Discover Packages
github.com/aelpxy/fresh
config
package
Version:
v0.0.0-...-f191575
Opens a new window with list of versions in this module.
Published: Feb 14, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type AuthConfig struct {
Enabled bool `toml:"enabled"`
Keys []AuthKey `toml:"keys"`
PublicEndpoints []string `toml:"public_endpoints"`
JWT JWTConfig `toml:"jwt"`
}
type AuthKey struct {
Key string `toml:"key"`
Name string `toml:"name"`
Permissions string `toml:"permissions"`
Buckets []string `toml:"buckets"`
}
type JWTConfig struct {
Enabled bool `toml:"enabled"`
Secrets []string `toml:"secrets"`
Issuer string `toml:"issuer"`
Audience string `toml:"audience"`
LeewaySec int64 `toml:"leeway_sec"`
}
type LifecycleConfig struct {
Enabled bool `toml:"enabled"`
CleanupIntervalSec int `toml:"cleanup_interval_sec"`
}
type PresignConfig struct {
Enabled bool `toml:"enabled"`
Secret string `toml:"secret"`
DefaultExpirySec int64 `toml:"default_expiry_sec"`
MaxExpirySec int64 `toml:"max_expiry_sec"`
}
type RateConfig struct {
Enabled bool `toml:"enabled"`
ReadPerSecond float64 `toml:"read_per_second"`
ReadBurst int `toml:"read_burst"`
WritePerSecond float64 `toml:"write_per_second"`
WriteBurst int `toml:"write_burst"`
CleanupInterval int `toml:"cleanup_interval"`
}
type ServerConfig struct {
Host string `toml:"host"`
Port int `toml:"port"`
Domain string `toml:"domain"`
TLS bool `toml:"tls"`
CertDir string `toml:"cert_dir"`
ReadTimeout int `toml:"read_timeout"`
WriteTimeout int `toml:"write_timeout"`
IdleTimeout int `toml:"idle_timeout"`
}
type StorageConfig struct {
Paths []string `toml:"paths"`
Database string `toml:"database"`
}
type UploadConfig struct {
MaxFileSize int64 `toml:"max_file_size"`
ChunkSize int64 `toml:"chunk_size"`
SessionTimeout int `toml:"session_timeout"`
CleanupInterval int `toml:"cleanup_interval"`
TempDir string `toml:"temp_dir"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.